FlareLightCurve
================

`FlareLightCurve`_ is the core class in **AltaiPony** for light curve de-trending, flare finding, and characterizing.

.. module:: altaipony.ffd

.. automodapi:: altaipony.flarelc
   :no-heading:
   :inherited-members:

